@@ -21,7 +21,7 @@
 #include "ldapcontrol.h"
 #include "ber.h"
 
-#include <QtCore/QSharedData>
+#include <QSharedData>
 
 using namespace KLDAP;
 
@@ -30,7 +30,6 @@ class LdapControlPrivate : public QSharedData
 public:
     LdapControlPrivate()
     {
-        mCritical = false;
     }
 
     LdapControlPrivate(const LdapControlPrivate &other)
@@ -43,7 +42,7 @@ public:
 
     QString mOid;
     QByteArray mValue;
-    bool mCritical;
+    bool mCritical = false;
 };
 
 LdapControl::LdapControl()
