@@ -27,28 +27,14 @@
 
 using namespace KLDAP;
 
-class Q_DECL_HIDDEN LdapStructureProxyModel::LdapStructureProxyModelPrivate
-{
-public:
-    LdapStructureProxyModelPrivate();
-
-};
-
-LdapStructureProxyModel::LdapStructureProxyModelPrivate::LdapStructureProxyModelPrivate()
-{
-
-}
-
 LdapStructureProxyModel::LdapStructureProxyModel(QObject *parent)
-    : QSortFilterProxyModel(parent),
-      m_d(new LdapStructureProxyModelPrivate())
+    : QSortFilterProxyModel(parent)
 {
 
 }
 
 LdapStructureProxyModel::~LdapStructureProxyModel()
 {
-    delete m_d;
 }
 
 QVariant LdapStructureProxyModel::data(const QModelIndex &index,
@@ -153,7 +139,7 @@ Qt::DropActions LdapStructureProxyModel::supportedDropActions() const
 QMimeData *LdapStructureProxyModel::mimeData(const QModelIndexList &indexes) const
 {
     Q_UNUSED(indexes);
-    return Q_NULLPTR;
+    return nullptr;
 }
 
 bool LdapStructureProxyModel::dropMimeData(const QMimeData *data, Qt::DropAction action,
